pub fn send_scroll_event(delta: f32, direction: ScrollDirection) -> Result<()>Expand description
Sends a scroll event to rotate the mouse wheel in the given direction.
pub fn send_scroll_event(delta: f32, direction: ScrollDirection) -> Result<()>Sends a scroll event to rotate the mouse wheel in the given direction.